==> OpenPatricianModel-0.9.0-RC1-sources.jar: ch/sahits/game/openpatrician/model/ModelConfiguration.java <==
package ch.sahits.game.openpatrician.model;

import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.city.cityhall.impl.FoundNewSettlement;
import ch.sahits.game.openpatrician.model.city.impl.City;
import ch.sahits.game.openpatrician.model.product.AmountablePrice;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.weapon.IWeapon;
import ch.sahits.game.openpatrician.utilities.IOpenPatricianUtilitiesComponents;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.service.RandomNameLoader;
import com.google.common.collect.Interner;
import com.google.common.collect.Interners;
import javafx.geometry.Point2D;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.PropertiesFactoryBean;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Scope;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

import java.util.Locale;
import java.util.Random;

/**
 * Java configuration of the spring context.
 * @author Andi Hotz, (c) Sahits GmbH, 2014
 *         Created on Feb 02, 2014
 */
@Configuration
@EnableAutoConfiguration
@ComponentScan(basePackageClasses = {IOpenPatricianUtilitiesComponents.class, ModelConfiguration.class})
@ClassCategory(EClassCategory.STARTUP)
public class ModelConfiguration {


    @Bean
    public Random rnd() {
        return new Random();
    }
    @Bean
    public Interner<Point2D> pointInterner() {
        return Interners.newStrongInterner();
    }

    @Bean
    public Jaxb2Marshaller jaxb2XmlModelMarshaller() {
        Jaxb2Marshaller bean = new Jaxb2Marshaller();
        bean.setContextPath("ch.sahits.game.openpatrician.data.xmlmodel");
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer applicationProperties(@Value("#{systemProperties['user.home']}") String userHome) {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("model-settings.properties"), new ClassPathResource("configuration.properties"),
                new FileSystemResource(userHome + "/.OpenPatrician/OpenPatricianConfiguration.properties")});
        return bean;
    }

    @Bean
    public PropertiesFactoryBean model() {
        PropertiesFactoryBean bean = new PropertiesFactoryBean();
        bean.setLocation(new ClassPathResource("populationConsume_default.properties"));
        return bean;
    }

    @Bean
    public Locale defaultLocale() {
        return Locale.ENGLISH;
    }

    @Bean
    public RandomNameLoader firstNameLoader() {
        return new RandomNameLoader("firstnames.properties");
    }

    @Bean
    public RandomNameLoader lastNameLoader() {
        return new RandomNameLoader("lastnames.properties");
    }

    @Bean
    public RandomNameLoader shipNameLoader() {
        return new RandomNameLoader("shipnames.properties");
    }

    @Bean
    public PropertiesFactoryBean modelProperties() {
        PropertiesFactoryBean propertyFact = new PropertiesFactoryBean();
        propertyFact.setLocation(new ClassPathResource("model.properties"));
        return propertyFact;
    }

    @Bean
    @Scope("prototype")
    public ICity cityBean(ch.sahits.game.openpatrician.data.xmlmodel.City cityData) {
        ICity city = new City(cityData);
        return city;
    }
    @Bean
    @Scope("prototype")
    public ICity cityBean(FoundNewSettlement cityData) {
        ICity city = new City(cityData);
        return city;
    }


    @Bean
    public ReloadableResourceBundleMessageSource messageSource() {
        ReloadableResourceBundleMessageSource bundle = new ReloadableResourceBundleMessageSource();
        bundle.setDefaultEncoding("UTF-8");
        bundle.setBasename("i18n/text");
        bundle.setFallbackToSystemLocale(false);
        return bundle;
    }
    @Bean
    @Scope("prototype")
    public BaseAmountable<IWeapon> weaponAmountable() {
        return new BaseAmountable<>();
    }

    @Bean
    @Scope("prototype")
    public AmountablePrice<IWare> wareAmountable() {
        return new AmountablePrice<>();
    }
}

==> OpenPatricianModel-0.9.1-RC1-sources.jar: ch/sahits/game/openpatrician/model/ModelConfiguration.java <==
package ch.sahits.game.openpatrician.model;

import ch.sahits.game.openpatrician.data.xmlmodel.map.Map;
import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.city.cityhall.impl.FoundNewSettlement;
import ch.sahits.game.openpatrician.model.city.impl.City;
import ch.sahits.game.openpatrician.model.product.AmountablePrice;
import ch.sahits.game.openpatrician.model.product.IWare;
import ch.sahits.game.openpatrician.model.weapon.IWeapon;
import ch.sahits.game.openpatrician.utilities.IOpenPatricianUtilitiesComponents;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.service.RandomNameLoader;
import com.google.common.collect.Interner;
import com.google.common.collect.Interners;
import javafx.geometry.Point2D;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.beans.factory.config.PropertiesFactoryBean;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Scope;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

import java.util.Locale;
import java.util.Random;

/**
 * Java configuration of the spring context.
 * @author Andi Hotz, (c) Sahits GmbH, 2014
 *         Created on Feb 02, 2014
 */
@Configuration
@EnableAutoConfiguration
@ComponentScan(basePackageClasses = {IOpenPatricianUtilitiesComponents.class, ModelConfiguration.class})
@ClassCategory(EClassCategory.STARTUP)
public class ModelConfiguration {


    @Bean
    public Random rnd() {
        return new Random();
    }
    @Bean
    public Interner<Point2D> pointInterner() {
        return Interners.newStrongInterner();
    }

    @Bean
    public Jaxb2Marshaller jaxb2XmlModelMarshallerMap() {
        Jaxb2Marshaller bean = new Jaxb2Marshaller();
        bean.setContextPath("ch.sahits.game.openpatrician.data.xmlmodel.map");
        return bean;
    }

    @Bean
    public Jaxb2Marshaller jaxb2XmlModelMarshallerWeapon() {
        Jaxb2Marshaller bean = new Jaxb2Marshaller();
        bean.setContextPath("ch.sahits.game.openpatrician.data.xmlmodel.weapon");
        return bean;
    }

    @Bean
    public static PropertyPlaceholderConfigurer applicationProperties(@Value("#{systemProperties['user.home']}") String userHome) {
        PropertyPlaceholderConfigurer bean = new PropertyPlaceholderConfigurer();
        bean.setIgnoreUnresolvablePlaceholders(true);
        bean.setLocations(new Resource[]{new ClassPathResource("model-settings.properties"), new ClassPathResource("configuration.properties"),
                new FileSystemResource(userHome + "/.OpenPatrician/OpenPatricianConfiguration.properties")});
        return bean;
    }

    @Bean
    public PropertiesFactoryBean model() {
        PropertiesFactoryBean bean = new PropertiesFactoryBean();
        bean.setLocation(new ClassPathResource("populationConsume_default.properties"));
        return bean;
    }

    @Bean
    public Locale defaultLocale() {
        return Locale.ENGLISH;
    }

    @Bean
    public RandomNameLoader firstNameLoader() {
        return new RandomNameLoader("firstnames.properties");
    }

    @Bean
    public RandomNameLoader lastNameLoader() {
        return new RandomNameLoader("lastnames.properties");
    }

    @Bean
    public RandomNameLoader shipNameLoader() {
        return new RandomNameLoader("shipnames.properties");
    }

    @Bean
    public PropertiesFactoryBean modelProperties() {
        PropertiesFactoryBean propertyFact = new PropertiesFactoryBean();
        propertyFact.setLocation(new ClassPathResource("model.properties"));
        return propertyFact;
    }

    @Bean
    @Scope("prototype")
    public ICity cityBean(Map.Cities.City cityData) {
        ICity city = new City(cityData);
        return city;
    }
    @Bean
    @Scope("prototype")
    public ICity cityBean(FoundNewSettlement cityData) {
        ICity city = new City(cityData);
        return city;
    }


    @Bean
    public ReloadableResourceBundleMessageSource messageSource() {
        ReloadableResourceBundleMessageSource bundle = new ReloadableResourceBundleMessageSource();
        bundle.setDefaultEncoding("UTF-8");
        bundle.setBasename("i18n/text");
        bundle.setFallbackToSystemLocale(false);
        bundle.setUseCodeAsDefaultMessage(true);
        return bundle;
    }
    @Bean
    @Scope("prototype")
    public BaseAmountable<IWeapon> weaponAmountable() {
        return new BaseAmountable<>();
    }

    @Bean
    @Scope("prototype")
    public AmountablePrice<IWare> wareAmountable() {
        return new AmountablePrice<>();
    }
}
